package cn.fw.hestia.sdk.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : DemoEnum
 * @description : 发送状态
 * @date: 2020-08-11 17:37
 */
public enum DemoEnum implements IEnum<Integer> {
    /**
     * 未处理
     */
    MADA(1, "未处理"),
    /**
     * 已处理
     */
    SUMI(2, "已处理"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    DemoEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static DemoEnum ofValue(final Integer value) {
        for (final DemoEnum demoEnum : DemoEnum.values()) {
            if (demoEnum.value.equals(value)) {
                return demoEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final DemoEnum demoEnum : DemoEnum.values()) {
            if (demoEnum.value.equals(value)) {
                return demoEnum.getName();
            }
        }
        return "";
    }
}
