package cn.fw.hestia.component;

import cn.fw.hestia.service.buz.MessageCenterBizService;
import cn.fw.passport.sdk.enums.SubScribeEventEnum;
import cn.fw.passport.sdk.mq.SubscribeEvent;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;


/**
 * 监听关注公众号mq
 *
 * @author kurisu
 */
@Slf4j
@Component
@RocketMQMessageListener(topic = "subs_event", consumerGroup = "${spring.application.name}" + "-subs_event")
public class AttentionConsumer implements RocketMQListener<SubscribeEvent> {
    private final MessageCenterBizService messageCenterBizService;

    @Autowired
    public AttentionConsumer(final MessageCenterBizService messageCenterBizService) {
        this.messageCenterBizService = messageCenterBizService;
    }

    @Override
    public void onMessage(SubscribeEvent t) {
        log.info("监听关注公众号mq: SubscribeEvent=[{}]", t);
        SubScribeEventEnum eventType = t.getEventType();
        try {
            if (eventType.equals(SubScribeEventEnum.SUBSCRIBE)) {
                messageCenterBizService.onAttention(t.getUserId());
            }
        } catch (Exception ex) {
            log.error("消费关注公众号mq失败，原因:{}", JSON.toJSONString(ex));
        }
    }
}